@@ -1,5 +1,4 @@
-from pyslz.pyslz import pytholino_alert
-from pyslz.pyslz import pytholino_error
+from pyslz.pyslz import send_alert
 from pyslz.pyslz import adjust_cpf
 from pyslz.pyslz import adjust_phone
 from pyslz.pyslz import adjust_cnpj
